@@ -363,6 +363,17 @@ setMethod('print', 'ggmultiplot',
 #' @return NULL
 setMethod('show', 'ggmultiplot', function(object) { print(object) })
 
+#' The implemented grid.draw method for ggmultiplot, in order to work
+#' with ggsave() properly
+#'
+#' @export
+#' @method grid.draw ggmultiplot
+#' @importFrom grid grid.draw
+#' @importFrom gridExtra arrangeGrob
+#' @param plot \code{ggmultiplot}
+grid.draw.ggmultiplot <- function(plot) {
+  grid::grid.draw(gridExtra::arrangeGrob(grobs = plot@plots))
+}
 
 #' Post process for fortify. Based on \code{ggplot2::qplot}
 #'
@@ -586,7 +597,7 @@ ggbiplot <- function(plot.data, loadings.data = NULL,
       p <- p + ggplot2::geom_polygon(data = hulls, mapping = mapping,
                                      alpha = frame.alpha)
     } else if (frame.type %in% c('t', 'norm', 'euclid')) {
-      mapping <- aes_string(colur = frame.colour, fill = frame.colour)
+      mapping <- aes_string(colour = frame.colour, fill = frame.colour)
       p <- p + ggplot2::stat_ellipse(mapping = mapping,
                                      level = frame.level, type = frame.type,
                                      geom = 'polygon', alpha = frame.alpha)
